==> thx_miscellaneous-0.0.2.tar.gz: thx_miscellaneous-0.0.2/thx/miscellaneous/admin.py <==
# -*- coding: utf-8 -*-
from django.contrib import admin
from django.urls import reverse, path
from django.utils.html import format_html
from django.utils.translation import gettext_lazy as _

from jmb.filters.admin import AdvancedSearchModelAdmin
from thx.core.admin import UserAdminMixin
from . import models, admin_views
from . import admin_widgets as widgets


class CommentAdmin(
    UserAdminMixin, AdvancedSearchModelAdmin, admin.ModelAdmin
):
    search_fields = ('title',)
    advanced_search_fields = (
        ('status',),
        ('title__icontains',),
        ('message__icontains',),
    )
    fieldsets = (
        (_('general information'), {
            'fields': (
                'type', 'is_public', 'title', 'message',
            )
        }),
        (_('visualization admin'), {
            'classes': ('collapse',),
            'fields': ('ordering', 'status')
        }),
        (_('logs admin'), {
            'classes': ('collapse',),
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify')
        }),
    )
    list_display = ('status', 'title', 'type', 'ordering')
    list_display_links = ('title',)
    readonly_fields = ('type', 'creator', 'date_create', 'last_modifier', 'date_last_modify')


class AttachmentAdmin(
    UserAdminMixin, AdvancedSearchModelAdmin, admin.ModelAdmin
):
    search_fields = ('name',)
    advanced_search_fields = (
        ('status',),
        ('name__icontains', 'type',),
    )
    list_filter = ('status',)
    fieldsets = (
        (_('general information'), {
            'fields': (
                'name', 'type', 'attachment', 'description',
            )
        }),
        (_('visualization admin'), {
            'classes': ('collapse',),
            'fields': ('ordering', 'status')
        }),
        (_('logs admin'), {
            'classes': ('collapse',),
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify')
        }),
    )
    list_display = ('id', 'status', 'name', 'type', 'download_link', 'ordering')
    list_display_links = ('name',)
    readonly_fields = ('type', 'creator', 'date_create', 'last_modifier', 'date_last_modify')

    def formfield_for_dbfield(self, db_field, **kwargs):
        if db_field.name == 'attachment':
            kwargs['widget'] = widgets.AttachmentWidget
        return super().formfield_for_dbfield(db_field, **kwargs)

    @staticmethod
    def download_link(obj):
        endpoint = reverse('admin:miscellaneous_attachment_download', args=(obj.id,))
        return format_html(f"<a href='{endpoint}' class='button'>{_('Download')}</a>")

    def get_urls(self):
        urls = super().get_urls()
        my_urls = [
            path(
                'download/<int:pk>/',
                self.admin_site.admin_view(admin_views.AttachmentDownloadView.as_view()),
                name='miscellaneous_attachment_download'
            )
        ]
        return my_urls + urls


admin.site.register(models.Comment, CommentAdmin)
admin.site.register(models.Attachment, AttachmentAdmin)

==> thx_miscellaneous-0.1.0.tar.gz: thx_miscellaneous-0.1.0/thx/miscellaneous/admin.py <==
# -*- coding: utf-8 -*-
from django.contrib import admin
from django.urls import path, reverse
from django.utils.html import format_html
from django.utils.translation import gettext_lazy as _
from jmb.filters.admin import AdvancedSearchModelAdmin
from thx.core.admin import UserAdminMixin

from . import admin_views, admin_widgets as widgets, models


class CommentAdmin(
    UserAdminMixin, AdvancedSearchModelAdmin, admin.ModelAdmin
):
    search_fields = ('title',)
    advanced_search_fields = (
        ('status',),
        ('title__icontains',),
        ('message__icontains',),
    )
    fieldsets = (
        (_('general information'), {
            'fields': (
                'type', 'is_public', 'title', 'message',
            )
        }),
        (_('visualization admin'), {
            'classes': ('collapse',),
            'fields': ('ordering', 'status')
        }),
        (_('logs admin'), {
            'classes': ('collapse',),
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify')
        }),
    )
    list_display = ('status', 'title', 'type', 'ordering')
    list_display_links = ('title',)
    readonly_fields = ('type', 'creator', 'date_create', 'last_modifier', 'date_last_modify')


class AttachmentAdmin(
    UserAdminMixin, AdvancedSearchModelAdmin, admin.ModelAdmin
):
    search_fields = ('name',)
    advanced_search_fields = (
        ('status',),
        ('name__icontains', 'type',),
    )
    list_filter = ('status',)
    fieldsets = (
        (_('general information'), {
            'fields': (
                'name', 'type', 'attachment', 'description',
            )
        }),
        (_('visualization admin'), {
            'classes': ('collapse',),
            'fields': ('ordering', 'status')
        }),
        (_('logs admin'), {
            'classes': ('collapse',),
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify')
        }),
    )
    list_display = ('id', 'status', 'name', 'type', 'download_link', 'ordering')
    list_display_links = ('name',)
    readonly_fields = ('type', 'creator', 'date_create', 'last_modifier', 'date_last_modify')

    def formfield_for_dbfield(self, db_field, **kwargs):
        if db_field.name == 'attachment':
            kwargs['widget'] = widgets.AttachmentWidget
        return super().formfield_for_dbfield(db_field, **kwargs)

    @staticmethod
    def download_link(obj):
        endpoint = reverse('admin:miscellaneous_attachment_download', args=(obj.id,))
        return format_html(f"<a href='{endpoint}' class='button'>{_('Download')}</a>")

    def get_urls(self):
        urls = super().get_urls()
        my_urls = [
            path(
                'download/<int:pk>/',
                self.admin_site.admin_view(admin_views.AttachmentDownloadView.as_view()),
                name='miscellaneous_attachment_download'
            )
        ]
        return my_urls + urls


admin.site.register(models.Comment, CommentAdmin)
admin.site.register(models.Attachment, AttachmentAdmin)
